From c67fe187667d1bde9df505d6102f914afc9763ae Mon Sep 17 00:00:00 2001
From: zzxwill <zzxwill@gmail.com>
Date: Sun, 10 Apr 2016 22:15:36 +0800
Subject: [PATCH] Correct some typos

During my review of the project, I corrected these typos
to make it more clear. If we will generate docs based on
the code, this will help.

Change-Id: Iee3d9210431e0489c4872637fe04409fe0addc0e
---
 senlinclient/common/sdk.py | 4 ++--
 senlinclient/v1/client.py  | 2 +-
 tools/senlinrc             | 2 +-
 3 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/senlinclient/v1/client.py b/senlinclient/v1/client.py
index 944eadad..4667fa9e 100644
--- a/senlinclient/v1/client.py
+++ b/senlinclient/v1/client.py
@@ -222,7 +222,7 @@ class Client(object):
         return self.service.cluster_scale_in(cluster, count)
 
     def cluster_policies(self, cluster, **queries):
-        """List all policies attached to clusdter
+        """List all policies attached to cluster
 
         Doc link:
         http://developer.openstack.org/api-ref-clustering-v1.html
diff --git a/tools/senlinrc b/tools/senlinrc
index 1fae0e82..59e898e0 100644
--- a/tools/senlinrc
+++ b/tools/senlinrc
@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 
-# IMPORTANT: Cleanse existing environment varible first
+# IMPORTANT: Cleanse existing environment variable first
 unset OS_USERNAME
 unset OS_PASSWORD
 unset OS_REGION_NAME
diff --git a/senlinclient/common/sdk.py b/senlinclient/common/sdk.py
index 48507442..65caead0 100644
--- a/senlinclient/common/sdk.py
+++ b/senlinclient/common/sdk.py
@@ -27,9 +27,9 @@ prop = base.prop
 
 
 class ProfileAction(argparse.Action):
     """A custom action to parse user proferences as key=value pairs
 
-    Stores results in users proferences object.
+    Stores results in users preferences object.
     """
     prof = profile.Profile()
 
@@ -27,9 +27,9 @@ prop = base.prop
 
 class ProfileAction(argparse.Action):
-    """A custom action to parse user proferences as key=value pairs
+    """A custom action to parse user preferences as key=value pairs
 